@@ -9,6 +9,8 @@
  *
  */
 
+#ifdef CONFIG_NET_NS
+
 #include <linux/module.h>
 #include <linux/slab.h>
 #include <linux/sched.h>
@@ -18,12 +20,8 @@
 #include <lttng/events-internal.h>
 #include <ringbuffer/frontend_types.h>
 #include <wrapper/vmalloc.h>
-#include <wrapper/namespace.h>
 #include <lttng/tracer.h>
 
-#if defined(CONFIG_NET_NS) && \
-	(LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,8,0))
-
 static
 size_t net_ns_get_size(void *priv, struct lttng_kernel_probe_ctx *probe_ctx, size_t offset)
 {
@@ -49,7 +47,7 @@ void net_ns_record(void *priv, struct lttng_kernel_probe_ctx *probe_ctx,
 	 * namespaces, just dereference the pointers.
 	 */
 	if (current->nsproxy)
-		net_ns_inum = current->nsproxy->net_ns->lttng_ns_inum;
+		net_ns_inum = current->nsproxy->net_ns->ns.inum;
 
 	chan->ops->event_write(ctx, &net_ns_inum, sizeof(net_ns_inum), lttng_alignof(net_ns_inum));
 }
@@ -69,7 +67,7 @@ void net_ns_get_value(void *priv,
 	 * namespaces, just dereference the pointers.
 	 */
 	if (current->nsproxy)
-		net_ns_inum = current->nsproxy->net_ns->lttng_ns_inum;
+		net_ns_inum = current->nsproxy->net_ns->ns.inum;
 
 	value->u.s64 = net_ns_inum;
 }
