@@ -103,17 +103,16 @@ struct trace_syscall_table {
 	const size_t len;
 };
 
-extern
 void syscall_entry_event_probe(void *__data, struct pt_regs *regs, long id);
 
-extern
 void syscall_exit_event_probe(void *__data, struct pt_regs *regs, long ret);
 
-extern
 void syscall_entry_event_notifier_probe(void *__data, struct pt_regs *regs,
 		long id);
-extern
 void syscall_exit_event_notifier_probe(void *__data, struct pt_regs *regs,
 		long ret);
 
+int lttng_syscall_tables_init(void);
+static inline void lttng_syscall_tables_exit(void) { }
+
 #endif /* LTTNG_SYSCALLS_H */
